Facetagr class
Constructors
- Facetagr()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
fnLogout(
) → Future< void> -
init(
{required String apiURL, required String clientID, required String externalID, required String hashcode, required String utcTime, required String requestID, bool allowUserRegistration = false}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
faceMatchStream
→ Stream<
String> -
no setter
-
initStream
→ Stream<
String> -
no setter
Static Methods
-
convertImageToBase64Jpg(
Uint8List imageBytes) → Future< String> -
detectFace(
Uint8List yuvData, int width, int height, int orientation) → Future< Map< String, dynamic> ?> -
initializeAndAwait(
{required String apiURL, required String clientID, required String externalID, required String hashcode, required String utcTime, required String requestID, bool allowUserRegistration = false}) → Future< Map< String, dynamic> >